Retrieves outside collaborators for a GitHub organisation. Outside collaborators have access to specific repositories but are not organisation members.
Usage
get_outside_collaborators(org, token = get_token())Retrieves outside collaborators for a GitHub organisation. Outside collaborators have access to specific repositories but are not organisation members.
get_outside_collaborators(org, token = get_token())