Retrieves all repos of a GitHub organisation.
Arguments
- org
A single character string giving the GitHub organisation or username whose repositories should be retrieved.
- limit
The maximum number of repositories to retrieve. The default is `Inf`, which retrieves all available repositories.
- token
A GitHub installation access token or personal access token. The default is `get_token()`, which returns a token generated by the GitHub App.
Details
The function queries the GitHub API endpoint: `GET /orgs/{org}/repos`
The data response includes metadata for each repository, such as its name, visibility, creation date, and issue counts. Use [tidy_repos] to convert this into a tidy data frame.